@@ -1394,9 +1394,13 @@ gboolean callback_keypress(GtkWidget *widget, GdkEventKey *event,
   {
   case GDK_F7:
     p_button_pressed=TRUE;
+    if (m_button_pressed) 
+	    callback_fullscreen(0, mainview);
     return TRUE;
   case GDK_F8:
     m_button_pressed=TRUE;
+    if (p_button_pressed) 
+	    callback_fullscreen(0, mainview);
     return TRUE;
   case GDK_F6:
     callback_fullscreen(0, mainview);
